@@ -95,7 +95,7 @@ KSldApp::KSldApp(QObject * parent)
     , m_powerManagementInhibition(new PowerManagementInhibition(this))
 {
     m_isX11 = QX11Info::isPlatformX11();
-    m_isWayland = QGuiApplication::platformName().startsWith( QLatin1String("wayland"), Qt::CaseInsensitive);
+    m_isWayland = QCoreApplication::instance()->property("platformName").toString().startsWith( QLatin1String("wayland"), Qt::CaseInsensitive);
 }
 
 KSldApp::~KSldApp()
@@ -572,6 +572,11 @@ void KSldApp::startLockProcess(EstablishLock establishLock)
     if (establishLock == EstablishLock::Immediate) {
         args << QStringLiteral("--immediateLock");
     }
+    if (establishLock == EstablishLock::DefaultToSwitchUser) {
+        args << QStringLiteral("--immediateLock");
+        args << QStringLiteral("--switchuser");
+    }
+
     if (m_lockGrace > 0) {
         args << QStringLiteral("--graceTime");
         args << QString::number(m_lockGrace);
